# tictactAI

Play against a tic tac toe AI in the shell, implemented with the minimax algorithm.

## Installation

```
pip install tictactai
```

## How to play

Open a new terminal or cmd and run:
```
tictactai
```

Alternatively, to play against a friend:
```
tictactai --pvp
```

Start the game and make subsequent moves by clicking on an empty position on the board.

Expanding the terminal/cmd window may be needed for optimal performance.